;************************************************************************
;*            Example for Divided / Normal Archive usage		*
;*----------------------------------------------------------------------*
;; Copyright (c) 1997-1998 David Kuehling

;; This software is provided 'as-is', without any express or implied
;; warranty. In no event will the authors be held liable for any damages
;; arising from the use of this software.

;; Permission is granted to anyone to use this software for any purpose,
;; including commercial applications, and to alter it and redistribute it
;; freely, subject to the following restrictions:

;; 1. The origin of this software must not be misrepresented; you must not
;;    claim that you wrote the original software. If you use this software
;;    in a product, an acknowledgment in the product documentation would be
;;    appreciated but is not required.
;; 2. Altered source versions must be plainly marked as such, and must not be
;;    misrepresented as being the original software.
;; 3. This notice may not be removed or altered from any source distribution.
;************************************************************************

	INCLUDE	"pk92lib.h"
	INCLUDE "gray4lib.h"
	INCLUDE "flib.h"

	XDEF	_main
	XDEF	_comment

; This file doesn't use the incude file, that is created automatically,
; when you compress a file with PACKER92.exe. But here it isn't useful,
; because the number of the file to uncompress is indicated by a counter,
; that is initialized to #0 (1st file) and counts up to 4 (5th file).
; Just for those who are interested, the file is included within the .zip
; file. it is named sample1.inc.

_main:
	jsr	gray4lib::on	;switch grayscale on
	tst.l	d0
	beq	\GrayError
        clr.w   d6              ;d6 = Number of file to uncompress = 1st file
    ;    ^-- move.w #sample11_2bp,d6 would be the same (if the sample.inc
    ;                                would be included into the program).
      
	; ----- uncompress file from Archive, specified by d0 ------
	lea	Archive(PC),a0
\Uncompress:
	move.w	d6,d0		;load Number of file to uncompress
	jsr	pk92lib::Extract
        tst.b   d0              ;if (d0 != 0) goto UncompressionError
        bne     \UncompressionError

	; ----- copy the uncompressed file to the 2 greyplanes -----
        move.w  #959,d7                 ;copy 960 longwords = 240x128 pixels
	move.l	gray4lib::plane1,a2
\PutPlane1:
	move.l	(a1)+,(a2)+
	dbra	d7,\PutPlane1

	move.w	#959,d7
	move.l	gray4lib::plane0,a2
\PutPlane2:
	move.l	(a1)+,(a2)+
	dbra	d7,\PutPlane2

	jsr	pk92lib::FreeMem	;unallocate the memory, used
					; for uncompression
	jsr	flib::idle_loop		;wait for keypress

	addq.w	#1,d6			;uncompress next file in Archive
	cmp.w	#5,d6
	beq	\End  			;if Number of file = 5 -> exit loop
	bra	\Uncompress
\End:
\UncompressionError:
	jsr	pk92lib::FreeMem

\GrayError:
	jsr	gray4lib::off

	rts

Archive:	INCBIN "d:\fargo0.2_3\mysource\pk92samp\sample1.p92"
		;      ^--- You should perhaps insert another directory here.
;	The Archive contains 5 Files, each of them is a 2 bitplane picture,
;       which size is 240x128. The planes follow each other, most significant
;	first, least significant last.

_comment:	dc.b	"PACKER92 - Sample #1",0

	END
