/* 
Copyright (c) 1997-1998 David Kuehling

This software is provided 'as-is', without any express or implied
warranty. In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not
   claim that you wrote the original software. If you use this software
   in a product, an acknowledgment in the product documentation would be
   appreciated but is not required.
2. Altered source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.
3. This notice may not be removed or altered from any source distribution.
*/
#include <stdio.h>
#include <time.h>
#include <fcntl.h>
#include <io.h>
#include <string.h>

enum ARCTYPES
{
  DIVIDED,
  NORMAL,
  SOLID,
  PROGDATA,
};


void PrintHelp ()
{
  printf ("\n\nHelp:");
  printf ("\n\tSyntax: packer92 -X [@]source1 [[@]source2] [...] destination");
  printf ("\n\t -X:");
  printf ("\n\t\t -n  create normal archive");
  printf ("\n\t\t -d  create divided archive");
  printf ("\n\t\t -s  create solid archive");
  printf ("\n\t\t -p  create program data archive");
  printf ("\n\t sourceX - name of source file \n\t\t(if -X is not -p, you can include up to 255 sourcefiles)");
  printf ("\n\t @sourceX - name of list-file, containing source files, divided by \n\t\tlinebreaks");
  printf ("\n\t destination - name of destination file \n\t\t(The file, which is included by INCBIN)");
  printf ("\n\t\tA destination file with the extention .inc\n\t\twill be created too, so don't use a .inc file \n\t\tas destination.");
}

void main (unsigned argn, char *args[])
{
  unsigned I;
  register int c, I2;
  enum ARCTYPES ArcType;
  static unsigned char	FileName[256][128],
			*PtrFlNm[256],
			FileNames;
  FILE *ListFile;


  fprintf (stderr, "\n\n\t\t  ---------------------------------------");
  fprintf (stderr,   "\n\t\t    PACKER92 - by David Khling 1997/98  ");
  fprintf (stderr,   "\n\t\t  ---------------------------------------\n");

  if (argn < 4 || (args[1][0] != '-' && args[1][0] != '/'))
  {
    PrintHelp ();
    exit (1);
  }

  switch (args[1][1])
  {
    case 'n': ArcType = NORMAL;
      break;
    case 'd': ArcType = DIVIDED;
      break;
    case 's': ArcType = SOLID;
      break;
    case 'p': ArcType = PROGDATA;
      break;
    default:
      printf ("\n\n\tUnknown command %s.", args[1]);
      PrintHelp ();
      exit (1);
  }

  /* Copy filenames to FileName */
  for (I = 2, FileNames = 0, PtrFlNm[0] = FileName[0]; I < argn-1; I++)
  {
    if (args[I][0] != '@')
    {
      PtrFlNm[FileNames] = FileName[FileNames];
      strcpy (FileName[FileNames++], args[I]);
    }
    else
    {
      if ((ListFile = fopen (&args[I][1], "rt")) == NULL)
      {
	printf ("\n\n\tERROR: can't open list-file: %s\n", &args[I][1]);
	exit (1);
      }
      for (I2 = 0;;)
      {
	if ((c = fgetc (ListFile)) == EOF)
	{
	  if (I2)
	    FileName[FileNames++][I2] = '\0';
	  break;
	}
	if (c == '\n')
	{
	  if (I2)
	    FileName[FileNames++][I2] = '\0';
	  if (FileNames >= 255)
	  {
	    printf ("\n\n\tERROR: More than 255 sourcefiles.\n");
	    exit (1);
	  }
	  I2 = 0;
	  PtrFlNm[FileNames] = FileName[FileNames];
	  continue;
	}
	if (I2 >= 127)
	{
	  printf ("\n\n\tERROR: Too long filename in list-file %s.\n", &args[I][1]);
	  exit (1);
	}
	FileName[FileNames][I2++] = c;
      }
      fclose (ListFile);
    }
  }

  PackArc (PtrFlNm, FileNames, args[argn-1], ArcType);
}
